@@ -400,9 +400,11 @@ def get_recent_year_income(symbol, company_info_type, exist_company_df):
         if data_frame_util.is_not_empty(exist_company_one_df):
             company_info_type['operate_profit'] = list(exist_company_one_df['operate_profit'])[0]
             company_info_type['total_operate_income'] = list(exist_company_one_df['total_operate_income'])[0]
+            company_info_type['operate_date_name'] = ''
         else:
             company_info_type['operate_profit'] = 0
             company_info_type['total_operate_income'] = 0
+            company_info_type['operate_date_name'] = ''
         return company_info_type
     query = {'symbol': symbol, "REPORT_TYPE": "年报"}
     em_stock_profit = mongodb_util.descend_query(query, db_name_constant.EM_STOCK_PROFIT, 'REPORT_DATE', 1)
@@ -439,5 +441,5 @@ if __name__ == '__main__':
     # query = {"total_operate_income": 0}
     # un_report_company_info = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
     # symbol_list = list(un_report_company_info['symbol'])
-    sync_company_base_info(None)
+    sync_company_base_info(['600753'])
     # group_by_industry()
