@@ -62,7 +62,6 @@ import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
 import mns_scheduler.industry.ths.ths_industry_sync_service as ths_industry_sync_service
 import mns_scheduler.k_line.year_quarter.year_quarter_line_sync as year_quarter_line_sync
 import mns_common.component.task.real_time_data_sync_check as real_time_data_sync_check
-import mns_scheduler.extraIncome.one_minute.one_minute_sync_task as one_minute_sync_task
 
 
 # 同步交易日期任务完成
@@ -426,12 +425,6 @@ def sync_ths_industry_info():
     logger.info("同步同花顺行业信息完成")
 
 
-# 同步1分钟交易数据
-def sync_one_minute_data():
-    logger.info("同步1分钟交易数据")
-    one_minute_sync_task.sync_one_minute_data()
-
-
 # 同步年线数据
 def sync_year_k_line():
     logger.info("同步年线数据")
@@ -454,7 +447,7 @@ blockingScheduler.add_job(sync_all_em_stock_info, 'cron', hour='15', minute='20'
 blockingScheduler.add_job(sync_today_trade_k_line_info, 'cron', hour='07', minute='50')
 
 # 同步单只股票下所有概念 by 股票代码
-blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='08,09,18', minute='00')
+blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='07,08,18', minute='45')
 
 # 打开交易客户端
 blockingScheduler.add_job(trader_client_auto_login, 'cron', hour='08,09', minute='04')
@@ -491,7 +484,7 @@ blockingScheduler.add_job(update_best_choose_plate_relation, 'cron', hour='09,18
 
 # 打开实时行情任务同步
 
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='25')
+blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='15')
 blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='29')
 blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='12', minute='59')
 # 关闭实时行情任务
@@ -510,12 +503,12 @@ blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='12', min
 blockingScheduler.add_job(col_data_move, 'cron', hour='15', minute='06')
 
 # 更新当天涨停股票池
-blockingScheduler.add_job(sync_stock_zt_pool, 'cron', hour='15,19', minute='25')
+blockingScheduler.add_job(sync_stock_zt_pool, 'cron', hour='15,19', minute='10')
 
 # todo 需要前后顺序执行
 # todo 当日k线信息
 # 同步一天k线 涨停 数据
-blockingScheduler.add_job(sync_daily_data_info, 'cron', hour='15,20', minute='26')
+blockingScheduler.add_job(sync_daily_data_info, 'cron', hour='15,20', minute='15')
 
 # (前复权--月k线)
 blockingScheduler.add_job(stock_sync_qfq_monthly, 'cron', hour='15,18', minute='35')
@@ -538,9 +531,6 @@ blockingScheduler.add_job(sync_financial_report_task, 'cron', hour='17', minute=
 # 同步同花顺行业信息
 blockingScheduler.add_job(sync_ths_industry_info, 'cron', hour='17,22', minute='38')
 
-# 同步一分钟交易数据
-blockingScheduler.add_job(sync_one_minute_data, 'cron', hour='17,22', minute='55')
-
 # 更新开盘啦指数历史指数
 blockingScheduler.add_job(sync_kpl_best_his_quotes, 'cron', hour='18,22', minute='25')
 
